import React, { useState } from "react";
import Loading from "../../util/Loading";
import Button from "../../util/Button";
import PlayerNameInput from "./PlayerNameInput";
import JoinGameInput from "./JoinGameInput";
import { createGame, joinGame } from "../../../domain/GGSHService";
import ms from "pretty-ms";

const NewGame = ({ onCreateGame, cannotCreateGame, timer, setTimer }) => {
  return (
    <div className="new-game">
      <div className="new-game__dropdown">
        <div className="new-game__dropdown-button">
          Round Timer: {ms(timer * 1000)}
        </div>
        <div className="new-game__dropdown-items">
          <div className="new-game__dropdown-option" onClick={() => setTimer(30)}>30 Seconds</div>
          <div className="new-game__dropdown-option" onClick={() => setTimer(300)}>5 Minutes</div>
          <div className="new-game__dropdown-option" onClick={() => setTimer(3600)}>1 Hour</div>
        </div>
      </div>
      <Button className="new-game__btn" onClick={onCreateGame} disabled={cannotCreateGame}>
        Create New Game
      </Button>
    </div>
  );
};

const PreGame = ({ initPlayerName, onGameJoined }) => {
  const [loading, setLoading] = useState(false);
  const [gameId, setGameId] = useState(null);
  const [playerName, setPlayerName] = useState(initPlayerName);
  const [timer, setTimer] = useState(300);

  if (loading) {
    return <Loading/>
  }

  const onChangePlayerName = ({ target }) => setPlayerName(target.value);
  const onChangeGameId = ({ target }) => setGameId(target.value.trim());
  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(playerName, timer);
    onGameJoined({ gameId, playerName });
  };
  const cannotCreateGame = !playerName || playerName.length === 0;
  const onJoinGame = async () => {
    // TODO would like to support re-joining a game you left
    setLoading(true);
    await joinGame(gameId, playerName);
    onGameJoined({ gameId, playerName });
  };
  const cannotJoinGame = cannotCreateGame || !gameId || gameId.length === 0;

  return (
    <div className="pre-game">
      <PlayerNameInput {...{ playerName, onChangePlayerName }} />
      <hr className="pre-game__divider"/>
      <NewGame {...{ onCreateGame, cannotCreateGame, timer, setTimer }} />
      <hr className="pre-game__divider"/>
      <JoinGameInput {...{ gameId, onChangeGameId, onJoinGame, cannotJoinGame }} />
    </div>
  );
}

export default PreGame;
